@@ -4,7 +4,7 @@
 ===============================================================================================================================
 ===============================================================================================================================
      This file is part of "luckyBackup" project
-     Copyright 2008-2009, Loukas Avgeriou
+     Copyright 2008-2010, Loukas Avgeriou
      luckyBackup is distributed under the terms of the GNU General Public License
      luckyBackup is free software: you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
  project version	: Please see "main.cpp" for project version
 
  developer 		: luckyb 
- last modified 		: 24 Nov 2009
+ last modified 		: 03 Mar 2010
 ===============================================================================================================================
 ===============================================================================================================================
 
@@ -50,10 +50,12 @@ class commandline
 
 		int count;		//simple count variable !!
 		QString CheckedData;	//String holding the ok - notOK message after the backup dirs check
-
+		
 	private:
 		char* profileNameArg;	//holds the profile as given at the command line
 		void intro();		//display an intro message
+		int errorCount;		// error counter for a specific task execution
+
 };
 
 #endif
