@@ -23,7 +23,7 @@
  project version	: Please see "main.cpp" for project version
 
  developer          : luckyb 
- last modified      : 17 Feb 2011
+ last modified      : 01 Jun 2011
 ===============================================================================================================================
 ===============================================================================================================================
  ********************************** DO NOT FORGET TO CHANGE "commandline.cpp:rsyncIT()" ********************************************************
@@ -561,6 +561,7 @@ void luckyBackupWindow::executeAfterTask()
 					}
 				}
 				snapfile.close();
+                filesAdded.remove("[LB]", Qt::CaseSensitive);        // just to make sure cause sometimes there are [LB]'s left
 			}
 
 			if (snapfile.open(QIODevice::WriteOnly))
@@ -1041,6 +1042,7 @@ void luckyBackupWindow::setNowDoing()
 					}
 				}
 				snapfile.close();
+                filesAdded.remove("[LB]", Qt::CaseSensitive);    // just to make sure cause sometimes there are [LB]'s left
 			}
 			if (snapfile.open(QIODevice::WriteOnly))
 			{
