@@ -23,7 +23,7 @@ cpp file that does all stuff needed when a signal is transmitted (eg button pres
 project version	: Please see "main.cpp" for project version
 
 developer       : luckyb 
-last modified   : 22 Feb 2011
+last modified   : 17 May 2011
 ===============================================================================================================================
 ===============================================================================================================================
 */
@@ -703,7 +703,7 @@ void luckyBackupWindow::duplicateTask()
 	ui.listWidget_operations -> currentItem() -> setCheckState(Qt::Unchecked);
 	TotalOperations = ui.listWidget_operations -> count();		//set the TotalOperations to what it is now
 
-    bool saveOrNot=FALSE;
+    saveOrNot=FALSE;
 	modify();	//open the modify dialog for the new task, FALSE == do not save the result
     saveOrNot = TRUE;
 
