@@ -23,7 +23,7 @@
  project version	: Please see "main.cpp" for project version
 
  developer 		: Loukas Avgeriou 
- last modified 		: 05 May 2010
+ last modified 		: 01 Sep 2010
 ===============================================================================================================================
 ===============================================================================================================================
 */
@@ -33,6 +33,8 @@
 
 #include "ui_manage.h"
 
+class CalcDiffThread;
+
 //==============================================================================================================
 //Declaration of manageDialog class (this is the dialog that manages existing backups of a task)
 
@@ -50,9 +52,12 @@ class manageDialog : public QDialog
 		void deleteBackup();	// launch the delete wizard
 		void fixGui();		// makes some changes to the gui according to various stuff
 		void SnapshotsListSelected();	//Triggered when selection changes
-		void calculateDifferences();	// calculate differences between source and snapshot
 		void hideSourceStuff();		// hide -show source stuff
 		
+		void calculateDifferences();	// calculate differences between source and snapshot
+		void calcDiffEnd();	// diffs have been calculated - update viewer with new text
+		void refreshDifWindow(const QString &, const bool &);	// update window with text concerning diff calculations
+		
 	private:
 		Ui::manageDialog uiG;
 		
@@ -66,12 +71,17 @@ class manageDialog : public QDialog
 		int currentSnaps;		// this is the current number of already created snapshots
 		int count;			//simple count variable
 		bool syncTYPE;			// This will become true if it is a sync task
-		bool sourceVisible;		// Helps to hide/show source stuff
-		QStringList calculatedDifferences;// Text of calculated deifferences is stores here for each snapshot
+		bool abortCalcThread;	// This will become true if the calculations thread is aborted
+		bool sourceVisible,viewLogVisible,deleteVisible,restoreVisible;		// Helps to hide/show source stuff
+		QStringList calculatedDifferences;// Text of calculated deifferences is stored here for each snapshot
 		QList<bool> snapCalculated;	// becomes true if differences have been calculated for a snapshot
 		
 		void updateSnapshots();
-		QString readDirEntries(QString);	// Read all entries of a directory except stuff we do not want to
+		
+		CalcDiffThread * calcdiffthread;	//thread to calculate differences between snap & source
+		
+	protected:
+		void closeEvent(QCloseEvent *event);
 }; 
 
 #endif
