@@ -22,7 +22,7 @@
  project version    : Please see "main.cpp" for project version
 
  developer          : luckyb 
- last modified      : 16 Feb 2011
+ last modified      : 18 May 2011
 ===============================================================================================================================
 ===============================================================================================================================
 */
@@ -38,6 +38,7 @@ manageWizard::manageWizard (QString type, QString SOURCE, QString DEST,  int sna
 	currentSnap = snapshot;							// this is the current snapshot number
 	snapshotsNo = Operation[currentOperation] -> GetSnapshotsListSize();	// this is the number of snapshots
 	wizard_type = type;
+    snapToRestore = snapshotsNo-2;  // This means the previous of the very last snapshot
 	
 	procRunning = FALSE;
 	procKilled = FALSE;
@@ -206,9 +207,19 @@ void manageWizard::startAction()
 void manageWizard::procFinished()
 {
 	procRunning = FALSE;
-	if ( (wizard_type == "restoreBackup") && (MainRun) && (currentSnap < snapshotsNo-1) )
+	if ( (wizard_type == "restoreBackup") && (snapToRestore >= currentSnap ) )
 	{
 		MainRun = FALSE;
+
+        time = Operation[currentOperation] -> GetSnapshotsListItem(snapToRestore);
+        QDir snapSpecificDir(dest + snapDefaultDir + time + SLASH);
+        if (snapSpecificDir.exists())
+            snapSpecificDirExists = TRUE;
+        else
+            snapSpecificDirExists = FALSE;
+        
+        snapToRestore--;
+        
 		runProcess();
 		return;
 	}
@@ -308,7 +319,7 @@ void manageWizard::abortAction()
 		commandProcess -> waitForFinished();
 	}
 	else
-		procFinished();		// the process might not be running for some wierd reason, so call procFinished !!
+		procFinished();		// the process might not be running for some weird reason, so call procFinished !!
 }
 // appendCommandOutput =====================================================================================================
 //update dialog with new data (text - progressbar) - also update logfile
@@ -424,66 +435,66 @@ void manageWizard::guiInitialize()
 // function to calculate command arguments for RESTORE
 void manageWizard::calcCommandArgs()
 {
-	commandArguments.clear();
-	commandArguments = AppendArguments(Operation[currentOperation]);
-	commandArguments.removeLast();	// remove the last 2 arguments (hopefuly source & destination)
-	commandArguments.removeLast();
+    commandArguments.clear();
+    commandArguments = AppendArguments(Operation[currentOperation]);
+    commandArguments.removeLast();	// remove the last 2 arguments (hopefuly source & destination)
+    commandArguments.removeLast();
 
-	// Scan the list and remove all arguments that are not needed
-	// keep all other arguments intact
-	count =0;
+    // Scan the list and remove all arguments that are not needed
+    // keep all other arguments intact
+    count =0;
 
-	while (count < commandArguments.size())
-	{
-		if 	(	(commandArguments[count].contains("--exclude"))	||
-				(commandArguments[count].contains("--include"))	||
-				(commandArguments[count] == "--prune-empty-dirs") ||
-				(commandArguments[count] == "-m") 		||
-				(commandArguments[count] == "--update")		||
-				(commandArguments[count] == "-u")		||
-				(commandArguments[count] == "--delay-updates")	||
-				(commandArguments[count].contains("--delete"))	||
-				(commandArguments[count].contains("--backup"))	||
-				(commandArguments[count].contains("--filter"))	||
-				(commandArguments[count].contains("--log"))	||
-				(commandArguments[count] == "--del")
-			)
-				commandArguments.removeAt(count);		//remove the argument if one of the above is true
-		else
-			count++;
-	}
-	
-	if (DryRun)
-		commandArguments.append("--dry-run");	// add --dry-run if checkbox checked
-		
-	if (MainRun)
-	{
-		//exclude the luckybackup snapshots directory cause it is inside the destination
-		commandArguments.append("--exclude=" + snapDefaultDir);
-		
-		//exclude stuff that have been backed-up, after the snapshot was made
-		//this means read the changes.logs files from every snapshot after the current one
-		count = currentSnap+1;
-		while (count < snapshotsNo)
-		{
-			commandArguments.append("--exclude-from=" + snapChangesDir + profileName + "-" + Operation[currentOperation] -> GetName() + "-" +
-						(Operation[currentOperation] -> GetSnapshotsListItem(count)) + ".changes.log");
-			count++;
-		}
+    while (count < commandArguments.size())
+    {
+        if 	(	(commandArguments[count].contains("--exclude"))	||
+                (commandArguments[count].contains("--include"))	||
+                (commandArguments[count] == "--prune-empty-dirs") ||
+                (commandArguments[count] == "-m") 		||
+                (commandArguments[count] == "--update")		||
+                (commandArguments[count] == "-u")		||
+                (commandArguments[count] == "--delay-updates")	||
+                (commandArguments[count].contains("--delete"))	||
+                (commandArguments[count].contains("--backup"))	||
+                (commandArguments[count].contains("--filter"))	||
+                (commandArguments[count].contains("--log"))	||
+                (commandArguments[count] == "--del")
+            )
+                commandArguments.removeAt(count);		//remove the argument if one of the above is true
+        else
+            count++;
+    }
+    
+    if (DryRun)
+        commandArguments.append("--dry-run");	// add --dry-run if checkbox checked
+        
+    //exclude stuff that have been backed-up, after the snapshot was made
+    //this means read the changes.logs files from every snapshot after the current one
+    count = currentSnap+1;
+    while (count < snapshotsNo)
+    {
+        commandArguments.append("--exclude-from=" + snapChangesDir + profileName + "-" + Operation[currentOperation] -> GetName() + "-" +
+                    (Operation[currentOperation] -> GetSnapshotsListItem(count)) + ".changes.log");
+        count++;
+    }
 
-		// add --delete options if checkbox checked
-		if (DeleteAfter)
-		{
-			commandArguments.append("--delete-after");
-			commandArguments.append("--delete-excluded");
-		}
-		
-		commandArguments.append(dest);	// set new dest as source Argument  - as it was calculated at manageWizard
-	}
-	else
-		commandArguments.append(dest + snapDefaultDir + time + SLASH + sourceLast);
-		
-	commandArguments.append(source);	// set new source as destination ...as it was calculated at manageWizard or changed by changeRestorePath
+    if (MainRun)
+    {
+        //exclude the luckybackup snapshots directory cause it is inside the destination
+        commandArguments.append("--exclude=" + snapDefaultDir);
+        
+        // add --delete options if checkbox checked
+        if (DeleteAfter)
+        {
+            commandArguments.append("--delete-after");
+            commandArguments.append("--delete-excluded");
+        }
+        
+        commandArguments.append(dest);	// set new dest as source Argument  - as it was calculated at manageWizard
+    }
+    else
+        commandArguments.append(dest + snapDefaultDir + time + SLASH + sourceLast);
+        
+    commandArguments.append(source);	// set new source as destination ...as it was calculated at manageWizard or changed by changeRestorePath
 }
 
 
@@ -507,7 +518,7 @@ void manageWizard::runProcess()
 			InfoMessage.append(tr("Restoring data: main trunk","info message displayed during ...data restoration"));
 		else
 		{
-			InfoMessage.append(tr("Restoring data: snapshot files","info message displayed during ...data restoration"));
+			InfoMessage.append(tr("Restoring data: snapshot files","info message displayed during ...data restoration") + " - " + time);
 			if (!snapSpecificDirExists)
 				skipTHIS = TRUE;
 		}
