@@ -23,7 +23,7 @@ Display a dialog. Adds a new or modifies an existing operation
  project version    : Please see "main.cpp" for project version
 
  developer          : luckyb 
- last modified      : 14 Feb 2011
+ last modified      : 17 May 2011
 
 ===============================================================================================================================
 ===============================================================================================================================
@@ -1020,13 +1020,12 @@ void modifyDialog::editListItem(const int type)
 // Moves an item within list, up one position
 void modifyDialog::moveListItemUp(const int type)
 {
-    int selected, totalListItems;
+    int selected;
     QListWidgetItem *tempItem;
     switch (type)
     {
         //exclude list
         case 0: selected = uiM.listWidget_exclude -> currentRow();          //current list row number
-            totalListItems = uiM.listWidget_exclude -> count();             //total no of list items
             if (selected < 0)                         //if nothing is selected do nothing
                 return;
             if (selected > 0)                       //if this is not the first row proceed with swapping items
@@ -1038,7 +1037,6 @@ void modifyDialog::moveListItemUp(const int type)
             break;
         //include list
         case 1: selected = uiM.listWidget_include -> currentRow();          //current list row number
-            totalListItems = uiM.listWidget_include -> count();             //total no of list items
             if (selected < 0)                           //if nothing is selected do nothing
                 return;
             if (selected > 0)                       //if this is not the first row proceed with swapping items
@@ -1050,7 +1048,6 @@ void modifyDialog::moveListItemUp(const int type)
             break;
         //options list
         case 2: selected = uiM.listWidget_options -> currentRow();          //current list row number
-            totalListItems = uiM.listWidget_options -> count();             //total no of list items
             if (selected < 0)                           //if nothing is selected do nothing
                 return;
             if (selected > 0)                       //if this is not the first row proceed with swapping items
@@ -1062,7 +1059,6 @@ void modifyDialog::moveListItemUp(const int type)
             break;
         //execute before
         case 3: selected = uiM.listWidget_executeBefore  -> currentRow();   //current list row number
-            totalListItems = uiM.listWidget_executeBefore -> count();       //total no of list items
             if (selected < 0)                           //if nothing is selected do nothing
                 return;
             if (selected > 0)                       //if this is not the first row proceed with swapping items
@@ -1074,7 +1070,6 @@ void modifyDialog::moveListItemUp(const int type)
             break;
         //execute after
         case 4: selected = uiM.listWidget_executeAfter -> currentRow();         //current list row number
-            totalListItems = uiM.listWidget_executeAfter -> count();             //total no of list items
             if (selected < 0)                           //if nothing is selected do nothing
                 return;
             if (selected > 0)                       //if this is not the first row proceed with swapping items
