@@ -1,31 +1,31 @@
-// ---------------------------------- patternEditor.cpp ---------------------------------------------------------------------------
-// Displays the pattern editor
+/* ---------------------------------- patternEditor.cpp ---------------------------------------------------------------------------
+ Displays the pattern editor
 
-//===============================================================================================================================
-//===============================================================================================================================
-//     This file is part of "luckyBackup" project
-//     Copyright 2008-2010, Loukas Avgeriou
-//     luckyBackup is distributed under the terms of the GNU General Public License
-//     luckyBackup is free software: you can redistribute it and/or modify
-//     it under the terms of the GNU General Public License as published by
-//     the Free Software Foundation, either version 3 of the License, or
-//     (at your option) any later version.
-// 
-//     luckyBackup is distributed in the hope that it will be useful,
-//     but WITHOUT ANY WARRANTY; without even the implied warranty of
-//     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-//     GNU General Public License for more details.
-// 
-//     You should have received a copy of the GNU General Public License
-//     along with luckyBackup.  If not, see <http://www.gnu.org/licenses/>.
+===============================================================================================================================
+===============================================================================================================================
+     This file is part of "luckyBackup" project
+     Copyright 2008-2011, Loukas Avgeriou
+     luckyBackup is distributed under the terms of the GNU General Public License
+     luckyBackup is free software: you can redistribute it and/or modify
+     it under the terms of the GNU General Public License as published by
+     the Free Software Foundation, either version 3 of the License, or
+     (at your option) any later version.
+ 
+     luckyBackup is distributed in the hope that it will be useful,
+     but WITHOUT ANY WARRANTY; without even the implied warranty of
+     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+     GNU General Public License for more details.
+ 
+     You should have received a copy of the GNU General Public License
+     along with luckyBackup.  If not, see <http://www.gnu.org/licenses/>.
 
 
-// project version	: Please see "main.cpp" for project version
+ project version	: Please see "main.cpp" for project version
 
-// developer 		: luckyb 
-// last modified 	: 27 Feb 2009
-//===============================================================================================================================
-//===============================================================================================================================
+ developer 		: luckyb 
+ last modified 	: 12 Feb 2011
+===============================================================================================================================
+===============================================================================================================================*/
 
 #include "patternEditor.h"
 
@@ -136,44 +136,49 @@ void patternEditor::resetFileds()
 //opens a QFileDialog to browse for files/folders locally
 void patternEditor::browse(const int type)
 {
-	QString newLineEdit;
-	switch (type)
-	{
-		//file browse button
-		case 0:	newLineEdit = QFileDialog::getOpenFileName (this, tr("Select file"),SourceRoot);
-			if (newLineEdit != "")	//if something is selected indeed (not cancel pressed)
-			{
-				if (!newLineEdit.startsWith(SourceRoot))
-				{
-					textDialog textdialogW ("QtWarning", tr("Please choose a file within the source")+" :<br><br>" +
-						SourceRoot, this);
-					textdialogW.exec();
-				}
-				else
-					uiP.lineEdit_browse 	-> setText(newLineEdit);
-			}
-			break;
-		//directory browse button
-		case 1: newLineEdit = QFileDialog::getExistingDirectory (this, tr("Select directory"),SourceRoot);
-			if (newLineEdit != "")	//if something is selected indeed (not cancel pressed)
-			{
-				if (!newLineEdit.endsWith("/"))
-					newLineEdit.append("/");
-					
-				if (newLineEdit == "//")
-						newLineEdit = "/";
-				
-				if (!newLineEdit.startsWith(SourceRoot))
-				{
-					textDialog textdialogW ("QtWarning", tr("Please choose a directory within the source")+" :<br><br>" +
-						SourceRoot, this);
-					textdialogW.exec();
-				}
-				else
-					uiP.lineEdit_browse  -> setText(newLineEdit);
-			}
-			break;
-	}
+    QString newLineEdit;
+    switch (type)
+    {
+        //file browse button
+        case 0:	newLineEdit = QFileDialog::getOpenFileName (this, tr("Select file"),SourceRoot);
+            if (OS2running)         // replace *nix slash with OS2 slash
+                newLineEdit.replace("/",SLASH);
+            if (newLineEdit != "")	//if something is selected indeed (not cancel pressed)
+            {
+                if (!newLineEdit.startsWith(SourceRoot))
+                {
+                    textDialog textdialogW ("QtWarning", tr("Please choose a file within the source")+" :<br><br>" +
+                        SourceRoot, this);
+                    textdialogW.exec();
+                }
+                else
+                    uiP.lineEdit_browse 	-> setText(newLineEdit);
+            }
+            break;
+        //directory browse button
+        case 1: newLineEdit = QFileDialog::getExistingDirectory (this, tr("Select directory"),SourceRoot);
+            if (newLineEdit != "")	//if something is selected indeed (not cancel pressed)
+            {
+                if (OS2running)         // replace *nix slash with OS2 slash
+                newLineEdit.replace("/",SLASH);
+                
+                if (!newLineEdit.endsWith(SLASH))
+                    newLineEdit.append(SLASH);
+                    
+                if (newLineEdit == "//")    // root selected - *nix
+                        newLineEdit = "/";
+                
+                if (!newLineEdit.startsWith(SourceRoot))
+                {
+                    textDialog textdialogW ("QtWarning", tr("Please choose a directory within the source")+" :<br><br>" +
+                        SourceRoot, this);
+                    textdialogW.exec();
+                }
+                else
+                    uiP.lineEdit_browse  -> setText(newLineEdit);
+            }
+            break;
+    }
 
 }
 //fillPattern ====================================================================================================================
@@ -215,18 +220,18 @@ void patternEditor::fillPattern()
 	{
 		patternLine = uiP.lineEdit_browse -> text();	//first get the string from the path lineEdit
 		if (patternLine.startsWith(SourceRoot))
-			patternLine.replace (SourceRoot, anchorSource + "/");	// replace the starting source in the pattern with /
+			patternLine.replace (SourceRoot, anchorSource + SLASH);	// replace the starting source in the pattern with /
 	}
 	
 	//go deeper in path ------------------- -------------------------------------------------------------------------------
 	if ( (uiP.checkBox_pathAny->isEnabled()) && (uiP.checkBox_pathAny->isChecked()) )
-		patternLine.append("**/");
+		patternLine.append("**"+SLASH);
 	else
 	{
 		count=0;
 		while ( (count < uiP.spinBox_pathDeeper->value()) && (uiP.spinBox_pathDeeper->isEnabled()))
 		{
-			patternLine.append("*/");
+			patternLine.append("*"+SLASH);
 			count++;
 		}
 	}
@@ -271,29 +276,29 @@ void patternEditor::fillPattern()
 		uiP.label_browse -> setVisible(TRUE);
 
 		uiP.label_browse -> setText(tr("file :"));
-		if (patternLine.endsWith("/"))
+		if (patternLine.endsWith(SLASH))
 			patternLine.chop(1);
 	}
 	if (uiP.radioButton_directorySpecific -> isChecked())	// if directory specific radio button is selected
 	{
 		uiP.label_browse -> setVisible(TRUE);
 		uiP.label_browse -> setText(tr("directory :"));
-		if ((!(patternLine.endsWith("/"))) && (!(patternLine == "")) )
-			patternLine.append("/");
+		if ((!(patternLine.endsWith(SLASH))) && (!(patternLine == "")) )
+			patternLine.append(SLASH);
 	}
 	if (uiP.radioButton_fileSet -> isChecked())		// if file set radio button is selected
 	{
 		uiP.checkBox_pathAbsolute -> setEnabled (TRUE);
 		uiP.label_browse -> setVisible(FALSE);
-		if (patternLine.endsWith("/"))
+		if (patternLine.endsWith(SLASH))
 			patternLine.chop(1);
 	}
 	if (uiP.radioButton_directorySet -> isChecked())	// if directory set radio button is selected
 	{
 		uiP.checkBox_pathAbsolute -> setEnabled (TRUE);
 		uiP.label_browse -> setVisible(FALSE);
-		if ( (!(patternLine.endsWith("/"))) && (!(patternLine == "")) )
-			patternLine.append("/");
+		if ( (!(patternLine.endsWith(SLASH))) && (!(patternLine == "")) )
+			patternLine.append(SLASH);
 	}
 	
 	//just the contents of a directory -------------------------------------------------------------------------------
